<?php

include('../../path.php');

require_once(ROOT_CONFIG);



    class modulo_app

    {

        public function insert_modulo_app($Titulo_Modulo, $Descripcion_Modulo, $Tipo_Menu, $Href_Modulo, $Icon_Fa_Modulo, $Status_Modulo, $Fecha_Registro, $Fecha_Modifico)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="INSERT INTO modulo_app_appquadrata(Titulo_Modulo, Descripcion_Modulo, Tipo_Menu, Href_Modulo, Icon_Fa_Modulo, Status_Modulo, Fecha_Registro, Fecha_Modifico) VALUES ('$Titulo_Modulo', '$Descripcion_Modulo', '$Tipo_Menu', '$Href_Modulo', '$Icon_Fa_Modulo', '$Status_Modulo', '$Fecha_Registro', '$Fecha_Modifico') ";

            $conexion->query($consulta);

            $whatsmyid=$conexion->insert_id;

            $conexion->close();

            return $whatsmyid;

        }



        public function get_modulo_app()

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT *,  count(*) as numregis FROM modulo_app_appquadrata WHERE (Id_Modulo_App!=1 and Id_Modulo_App!=2) ORDER BY Id_Modulo_App DESC";

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function get_modulo_apppg($inicio,$TAMANO_PAGINA)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT * FROM modulo_app_appquadrata WHERE (Id_Modulo_App!=1 and Id_Modulo_App!=2) ORDER BY Id_Modulo_App DESC";

            if ($TAMANO_PAGINA != "Todos") {

                $consulta .= " LIMIT $inicio, $TAMANO_PAGINA";

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function update_modulo_app($Id_Modulo_App, $Titulo_Modulo, $Descripcion_Modulo, $Tipo_Menu, $Href_Modulo, $Icon_Fa_Modulo, $Status_Modulo, $Fecha_Registro, $Fecha_Modifico)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="UPDATE modulo_app_appquadrata SET Id_Modulo_App='$Id_Modulo_App', Titulo_Modulo='$Titulo_Modulo', Descripcion_Modulo='$Descripcion_Modulo', Tipo_Menu='$Tipo_Menu', Href_Modulo='$Href_Modulo', Icon_Fa_Modulo='$Icon_Fa_Modulo', Fecha_Modifico='$Fecha_Modifico' WHERE Id_Modulo_App = '$Id_Modulo_App'";

            $conexion->query($consulta);

            $rowaffected=$conexion->affected_rows;

            $conexion->close();

            return $rowaffected;

        }



        public function delete_modulo_app($Id_Modulo_App)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="DELETE FROM modulo_app_appquadrata WHERE Id_Modulo_App='$Id_Modulo_App'";

            $conexion->query($consulta);

            $rowaffected=$conexion->affected_rows;

            $conexion->close();

            return $rowaffected;

        }



        //Funciones adicionales.

        public function getorderby_modulo_app($Nombre,$Orderby)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT *,  count(*) as numregis FROM modulo_app_appquadrata ORDER BY $Nombre $Orderby";

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function getorderby_modulo_apppg($Nombre,$Orderby,$inicio,$TAMANO_PAGINA)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT * FROM modulo_app_appquadrata ORDER BY $Nombre $Orderby";

            if ($TAMANO_PAGINA != "Todos") {

                $consulta .= " LIMIT $inicio, $TAMANO_PAGINA";

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function getbyid_modulo_app($Id_Modulo_App)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT * FROM modulo_app_appquadrata WHERE Id_Modulo_App='$Id_Modulo_App' ORDER BY Id_Modulo_App DESC";

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function search_modulo_app($Buscar)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT *, count(*) as numregis FROM modulo_app_appquadrata WHERE (Id_Modulo_App LIKE '%$Buscar%' || Titulo_Modulo LIKE '%$Buscar%' || Descripcion_Modulo LIKE '%$Buscar%' || Tipo_Menu LIKE '%$Buscar%' || Href_Modulo LIKE '%$Buscar%' || Icon_Fa_Modulo LIKE '%$Buscar%' || Status_Modulo LIKE '%$Buscar%' || Fecha_Registro LIKE '%$Buscar%' || Fecha_Modifico LIKE '%$Buscar%') AND Id_Modulo_App!=1 AND Id_Modulo_App!=2 ORDER BY Id_Modulo_App DESC";

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function search_modulo_apppg($Buscar,$inicio,$TAMANO_PAGINA)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT * FROM modulo_app_appquadrata WHERE (Id_Modulo_App LIKE '%$Buscar%' || Titulo_Modulo LIKE '%$Buscar%' || Descripcion_Modulo LIKE '%$Buscar%' || Tipo_Menu LIKE '%$Buscar%' || Href_Modulo LIKE '%$Buscar%' || Icon_Fa_Modulo LIKE '%$Buscar%' || Status_Modulo LIKE '%$Buscar%' || Fecha_Registro LIKE '%$Buscar%' || Fecha_Modifico LIKE '%$Buscar%') AND Id_Modulo_App!=1 AND Id_Modulo_App!=2 ORDER BY Id_Modulo_App DESC";

            if ($TAMANO_PAGINA != "Todos") {

                $consulta .= " LIMIT $inicio, $TAMANO_PAGINA";

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function searchbyparameter_modulo_app($Parametro,$Buscar)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT * FROM modulo_app_appquadrata WHERE $Parametro LIKE '%$Buscar%' ORDER BY Id_Modulo_App DESC";

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }

  

        public function execute_modulo_app($query)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $Array_adapter=$conexion->query($query);

            $conexion->close();

            return $Array_adapter;

        }



        public function update_field_modulo_app($Field,$Value,$Id_Modulo_App)

        {

            $Valueinto=strtoupper($Value);

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="UPDATE modulo_app_appquadrata SET $Field='$Valueinto' WHERE Id_Modulo_App= '$Id_Modulo_App'";

            $conexion->query($consulta);

            $rowaffected=$conexion->affected_rows;

            $conexion->close();

            return $rowaffected;                          

        }



        public function update_field_front_modulo_app($Field,$Value,$Id_Modulo_App)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="UPDATE modulo_app_appquadrata SET $Field='$Value' WHERE Id_Modulo_App= '$Id_Modulo_App'";

            $conexion->query($consulta);

            $rowaffected=$conexion->affected_rows;

            $conexion->close();

            return $rowaffected;                          

        }



}



?>