<?php

include('../../path.php');

require_once(ROOT_CONTROLLER.'modulo_app.php');

$Obj_modulo_app = new modulo_app();

require_once(ROOT_CHARACTER_FIX);

//require_once($context_modulo_app.'bussines/fix_characters.php');

$Obj_fix_characters = new fix_characters();



$action=!empty($_REQUEST['action'])?$_REQUEST['action']:'';

$_ScrollTo=!empty($_REQUEST['_ScrollTo'])?$_REQUEST['_ScrollTo']:'';

$_Pagina=!empty($_REQUEST['_Pagina'])?$_REQUEST['_Pagina']:'';



if (!empty($_POST))

{

    $Id_Modulo_App=!empty($_REQUEST['Id_Modulo_App'])?$_REQUEST['Id_Modulo_App']:'';

   $Titulo_Modulo=!empty($_REQUEST['Titulo_Modulo'])?$_REQUEST['Titulo_Modulo']:'';

   $Descripcion_Modulo=!empty($_REQUEST['Descripcion_Modulo'])?$_REQUEST['Descripcion_Modulo']:'';

   $Tipo_Menu=!empty($_REQUEST['Tipo_Menu'])?$_REQUEST['Tipo_Menu']:'';

   $Href_Modulo=!empty($_REQUEST['Href_Modulo'])?$_REQUEST['Href_Modulo']:'';

   $Icon_Fa_Modulo=!empty($_REQUEST['Icon_Fa_Modulo'])?$_REQUEST['Icon_Fa_Modulo']:'';

   $Status_Modulo=!empty($_REQUEST['Status_Modulo'])?$_REQUEST['Status_Modulo']:'';

   $Fecha_Registro=!empty($_REQUEST['Fecha_Registro'])?$_REQUEST['Fecha_Registro']:'';

   $Fecha_Modifico=!empty($_REQUEST['Fecha_Modifico'])?$_REQUEST['Fecha_Modifico']:'';

   

    $Field=!empty($_REQUEST['Field'])?$_REQUEST['Field']:''; 

    $Field=$Obj_fix_characters->fix($Field);

    $Value=!empty($_REQUEST['Value'])?$_REQUEST['Value']:''; 

    $Value=$Obj_fix_characters->fix($Value);

    $Value_Hidden=!empty($_REQUEST['Value_Hidden'])?$_REQUEST['Value_Hidden']:''; 

    $Value_Hidden=$Obj_fix_characters->fix($Value_Hidden);

    $Type=!empty($_REQUEST['Type'])?$_REQUEST['Type']:''; 

    $Type=$Obj_fix_characters->fix($Type);



}    



switch ($action) {

    case 'campos_front':

            $Obj_usuario->update_field_front_modulo_app($Field,$Value,$Id_Modulo_App);

        }catch (Exception $e) {

            echo 'Excepcion capturada: ',  $e->getMessage(), "\n";

        }

        break;



    case 'campos':

        try{

            $Obj_modulo_app->update_field_modulo_app($Field,$Value,$Id_Modulo_App);

            //$locations="Location: ./#$Id_Modulo_App";

            //header($locations);

            }   

        catch (Exception $e) {

            echo 'Excepcion capturada: ',  $e->getMessage(), "\n";

        }

        break;



    

    case 'editar':



        try{

             $Obj_modulo_app->update_modulo_app($Id_Modulo_App, $Titulo_Modulo, $Descripcion_Modulo, $Tipo_Menu, $Href_Modulo, $Icon_Fa_Modulo, $Status_Modulo, $Fecha_Registro, $Fecha_Modifico);

              $locations="Location: ../view/?pagina=$_Pagina&_Id_Registro=$Id_Modulo_App&_ScrollTo=$_ScrollTo";

              header($locations);

            }   

        catch (Exception $e) {

            echo 'Excepcion capturada: ',  $e->getMessage(), "\n";

        }

        break;



           case 'registrar':



        try{



         $idtupla=$Obj_modulo_app->insert_modulo_app($Titulo_Modulo, $Descripcion_Modulo, $Tipo_Menu, $Href_Modulo, $Icon_Fa_Modulo, $Status_Modulo, $Fecha_Registro, $Fecha_Modifico);

            $locations="Location: ../view/?pagina=1&_Id_Registro=$idtupla&_ScrollTo=0";

            header($locations);        

           }    

        catch (Exception $e) {

            echo 'Excepcion capturada: ',  $e->getMessage(), "\n";

        }   



        break;

        case 'duplicar':



        try{



         $idtupla=$Obj_modulo_app->insert_modulo_app($Titulo_Modulo, $Descripcion_Modulo, $Tipo_Menu, $Href_Modulo, $Icon_Fa_Modulo, $Status_Modulo, $Fecha_Registro, $Fecha_Modifico);

            $locations="Location: ../view/?pagina=1&_Id_Registro=$idtupla&_ScrollTo=0";

            header($locations);        

           }    

        catch (Exception $e) {

            echo 'Excepcion capturada: ',  $e->getMessage(), "\n";

        }   



        break;

        case 'eliminar':           

                try{

              $Obj_modulo_app->delete_modulo_app($Id_Modulo_App);

                 $locations ="Location: ../view";

                 header($locations);

                }

        

                catch (Exception $e) {

                    echo 'Excepcion capturada: ',  $e->getMessage(), "\n";

                }   



        break;



    default:

        

        break;

}

?>

